@@ -1,30 +1,40 @@
 skip_msg <- "System clipboard is not available - skipping test."
 context("Clipr read and write")
 
+is_clipr_available <- clipr_available()
+
+test_that("clipr_available fails when DISPLAY is not configured; succeeds when it is", {
+  # Only run this test on Travis
+  skip_if_not(identical(Sys.getenv("TRAVIS"), "true"))
+  if (identical(Sys.getenv("DISPLAY"), ""))
+    expect_false(is_clipr_available)
+  if (identical(Sys.getenv("DISPLAY"), ":99.0")) {
+    expect_true(is_clipr_available)
+  }
+})
+
 test_that("Unavailable clipboard throws warning", {
-  if (clipr_available()) {
-    expect_equivalent(write_clip("a"), "a")
-  } else {
+  if (!is_clipr_available) {
     expect_error(write_clip("a"))
   }
 })
 
 test_that("clipr_available() does not overwrite existing contents", {
-  skip_if_not(clipr_available(), skip_msg)
+  skip_if_not(is_clipr_available, skip_msg)
   write_clip("z")
   clipr_available()
   expect_equal(read_clip(), "z")
 })
 
 test_that("Render character vectors", {
-  skip_if_not(clipr_available(), skip_msg)
+  skip_if_not(is_clipr_available, skip_msg)
 
   single <- "hello, world!"
   expect_equivalent(write_clip(single), single)
 })
 
 test_that("Render default multiline vectors", {
-  skip_if_not(clipr_available(), skip_msg)
+  skip_if_not(is_clipr_available, skip_msg)
 
   multiline <- c("hello", "world!")
   inv_out <- write_clip(multiline)
@@ -37,7 +47,7 @@ test_that("Render default multiline vectors", {
 })
 
 test_that("Render custom multiline vectors", {
-  skip_if_not(clipr_available(), skip_msg)
+  skip_if_not(is_clipr_available, skip_msg)
 
   multiline <- c("hello", "world!")
   inv_out <- write_clip(multiline, breaks = ", ")
@@ -46,7 +56,7 @@ test_that("Render custom multiline vectors", {
 })
 
 test_that("Render default data.frames", {
-  skip_if_not(clipr_available(), skip_msg)
+  skip_if_not(is_clipr_available, skip_msg)
 
   tbl <- data.frame(a = c(1,2,3), b = c(4,5,6))
   inv_out <- write_clip(tbl)
@@ -59,7 +69,7 @@ test_that("Render default data.frames", {
 })
 
 test_that("Render custom data.frames", {
-  skip_if_not(clipr_available(), skip_msg)
+  skip_if_not(is_clipr_available, skip_msg)
 
   tbl <- data.frame(a = c(1,2,3), b = c(4,5,6))
   inv_out <- write_clip(tbl, sep = ",")
@@ -72,7 +82,7 @@ test_that("Render custom data.frames", {
 })
 
 test_that("Render matricies", {
-  skip_if_not(clipr_available(), skip_msg)
+  skip_if_not(is_clipr_available, skip_msg)
 
   tbl <- matrix(c(1, 2, 3, 4, 5, 6), nrow = 3, ncol = 2)
   inv_out <- write_clip(tbl)
@@ -85,7 +95,7 @@ test_that("Render matricies", {
 })
 
 test_that("Render custom matricies", {
-  skip_if_not(clipr_available(), skip_msg)
+  skip_if_not(is_clipr_available, skip_msg)
 
   tbl <- matrix(c(1, 2, 3, 4, 5, 6), nrow = 3, ncol = 2)
   inv_out <- write_clip(tbl, sep = ",")
@@ -98,7 +108,7 @@ test_that("Render custom matricies", {
 })
 
 test_that("Render tables read from clipboard as data.frames", {
-  skip_if_not(clipr_available(), skip_msg)
+  skip_if_not(is_clipr_available, skip_msg)
 
   inv_out <- write_clip(iris[1:2, 1:4])
   expect_equivalent(read_clip_tbl(), iris[1:2, 1:4])
